summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorlevine <levine@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1997-12-16 15:22:07 +0000
committerlevine <levine@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1997-12-16 15:22:07 +0000
commit16fe7832c2c42bc536d43b36582e17a404bde048 (patch)
tree952d463f6b7bd507aedac2368c05698b0a86adf5
parent7d382d07ba907bd8acceaaba6f7bbff0055d1751 (diff)
downloadATCD-16fe7832c2c42bc536d43b36582e17a404bde048.tar.gz
replace use of ! ACE_HAS_64BIT_LONGS with ACE_SIZEOF_LONG == 4
-rw-r--r--tests/Time_Value_Test.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/tests/Time_Value_Test.cpp b/tests/Time_Value_Test.cpp
index fcca669628e..c4a04cff4ac 100644
--- a/tests/Time_Value_Test.cpp
+++ b/tests/Time_Value_Test.cpp
@@ -23,10 +23,10 @@
#include "ace/config.h"
// Force test of ACE_U_LongLong class on all platforms except
// ACE_WIN32 and with ACE_HAS_64BIT_LONGS. ACE_U_LongLong isn't used
// on those platforms.
#if defined (ACE_HAS_HI_RES_TIMER) || \
- (defined (ACE_HAS_LONGLONG_T) && !defined (ACE_HAS_64BIT_LONGS))
+ (defined (ACE_HAS_LONGLONG_T) && (ACE_SIZEOF_LONG == 4))
# include <limits.h>
# undef ULLONG_MAX
@@ -45,12 +45,12 @@
# if defined (ACE_NO_INLINE)
# undef ACE_NO_INLINE
# endif /* ACE_NO_INLINE */
-#endif /* ACE_HAS_HI_RES_TIMER || (ACE_HAS_LONGLONG_T && !ACE_HAS_64BIT_LONGS) */
+#endif /* ACE_HAS_HI_RES_TIMER || (ACE_HAS_LONGLONG_T && ACE_SIZEOF_LONG == 4) */
#include "test_config.h"
#include "ace/ACE.h"
-#if !defined (ACE_WIN32) && !defined (ACE_HAS_64BIT_LONGS)
+#if !defined (ACE_WIN32) && (ACE_SIZEOF_LONG == 4)
static
u_long
@@ -109,7 +109,7 @@ test_ace_u_longlong ()
return errors;
}
-#endif /* ! ACE_WIN32 && ! ACE_HAS_64BIT_LONGS */
+#endif /* ! ACE_WIN32 && ACE_SIZEOF_LONG == 4 */
int
@@ -139,9 +139,9 @@ main (int, char *[])
ACE_ASSERT (tv6 == tv1);
ACE_ASSERT (tv5 == tv7);
-#if !defined (ACE_WIN32) && !defined (ACE_HAS_64BIT_LONGS)
+#if !defined (ACE_WIN32) && (ACE_SIZEOF_LONG == 4)
if (test_ace_u_longlong () != 0) ++ret;
-#endif /* ! ACE_WIN32 && ! ACE_HAS_64BIT_LONGS */
+#endif /* ! ACE_WIN32 && ACE_SIZEOF_LONG == 4 */
ACE_END_TEST;
return ret;
@@ -23,10 +23,10 @@
#include "ace/config.h"
// Force test of ACE_U_LongLong class on all platforms except
-// ACE_WIN32 and with ACE_HAS_64BIT_LONGS. ACE_U_LongLong isn't used
-// on those platforms.
+// ACE_WIN32 and with ACE_SIZEOF_LONG == 8. ACE_U_LongLong isn't
+// used on those platforms.
#if defined (ACE_HAS_HI_RES_TIMER) || \